
## CATO-CLI - mutation.site.updateSecondaryAzureVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.updateSecondaryAzureVSocket) for documentation on this operation.

### Usage for mutation.site.updateSecondaryAzureVSocket:

`catocli mutation site updateSecondaryAzureVSocket -h`

`catocli mutation site updateSecondaryAzureVSocket <json>`

`catocli mutation site updateSecondaryAzureVSocket "$(cat < mutation.site.updateSecondaryAzureVSocket.json)"`

`catocli mutation site updateSecondaryAzureVSocket '{"updateSecondaryAzureVSocketInput":{"floatingIp":"example_value","id":"id","interfaceIp":"example_value"}}'`

`catocli mutation site updateSecondaryAzureVSocket -p '{
    "updateSecondaryAzureVSocketInput": {
        "floatingIp": "example_value",
        "id": "id",
        "interfaceIp": "example_value"
    }
}'`


#### Operation Arguments for mutation.site.updateSecondaryAzureVSocket ####

`accountId` [ID] - (required) N/A    
`updateSecondaryAzureVSocketInput` [UpdateSecondaryAzureVSocketInput] - (required) N/A    
